@@ -71,6 +71,9 @@ OAUTH2_AUDIENCES: tuple = environ.parselist(
     os.environ, 'OAUTH2_AUDIENCES', sep=';'
 )
 
+#: The ``iss`` claim for tokens issued by this system.
+OAUTH2_ISSUER: str = os.getenv('OAUTH2_ISSUER')
+
 #: The list of Security Token Services (STSs) that the application trusts. The
 #: services are expected to provide a ``/.well-known/openid-configuration``
 #: URL, from which the JWKS holding its keys can be discovered. Multiple STSs
